Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDavid Williams2014-09-07 20:18:50 +0000
committerDavid Williams2014-09-07 20:18:50 +0000
commitef4156f1b43b0e7a464dcb6556e6e81ffbc45844 (patch)
treeb7f762bef9c5a31c7dbcfee4629c54df89d2e2ad /production/testScripts
parent658284315faef08d01468a756edba030e668153d (diff)
downloadeclipse.platform.releng.aggregator-ef4156f1b43b0e7a464dcb6556e6e81ffbc45844.tar.gz
eclipse.platform.releng.aggregator-ef4156f1b43b0e7a464dcb6556e6e81ffbc45844.tar.xz
eclipse.platform.releng.aggregator-ef4156f1b43b0e7a464dcb6556e6e81ffbc45844.zip
Use consistent "local includes" for local testing
Diffstat (limited to 'production/testScripts')
-rw-r--r--production/testScripts/configuration/sdk.tests/testConfigs/linux/testAll.sh6
-rw-r--r--production/testScripts/configuration/sdk.tests/testConfigs/linux32/testAll.sh6
-rw-r--r--production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh4
-rw-r--r--production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh4
-rw-r--r--production/testScripts/configuration/sdk.tests/testScripts/runtests.sh2
-rw-r--r--production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh2
-rwxr-xr-xproduction/testScripts/configuration/sdk.tests/testScripts/testTestXMLScript.sh2
-rwxr-xr-xproduction/testScripts/startTests.sh4
-rwxr-xr-xproduction/testScripts/test_runTests2.xml.sh4
9 files changed, 17 insertions, 17 deletions
diff --git a/production/testScripts/configuration/sdk.tests/testScripts/runtests.sh b/production/testScripts/configuration/sdk.tests/testScripts/runtests.sh
index 147f64269..c29e83643 100644
--- a/production/testScripts/configuration/sdk.tests/testScripts/runtests.sh
+++ b/production/testScripts/configuration/sdk.tests/testScripts/runtests.sh
@@ -10,7 +10,7 @@ echo "command line (quoted) as passed into $(basename ${0}): ${@}"
# for non-production builds.
export PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:~/bin
-source localTestsProperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
# should already be defined, by now, in production tests
diff --git a/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh b/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh
index 37194f525..1dc72834c 100644
--- a/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh
+++ b/production/testScripts/configuration/sdk.tests/testScripts/runtestsmac.sh
@@ -7,7 +7,7 @@
# to those defined by defaults for production machine.,
# such as for vmcmd
-source localTestsProperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
# by default, use the java executable on the path for outer and test jvm
#vmcmd=/shared/common/jdk-1.6.x86_64/jre/bin/java
diff --git a/production/testScripts/configuration/sdk.tests/testScripts/testTestXMLScript.sh b/production/testScripts/configuration/sdk.tests/testScripts/testTestXMLScript.sh
index 20f240c10..a96e1b533 100755
--- a/production/testScripts/configuration/sdk.tests/testScripts/testTestXMLScript.sh
+++ b/production/testScripts/configuration/sdk.tests/testScripts/testTestXMLScript.sh
@@ -1,6 +1,6 @@
#!/usr/bin/env bash
-source localbuildproperties.shsource
+source localBuildProperties.shsource
# Utility to test the test.xml file. It's intended to allow rapid confirmation
# that the test.xml file ends up "computing" correct values, for various versions
diff --git a/production/testScripts/test_runTests2.xml.sh b/production/testScripts/test_runTests2.xml.sh
index 1e64073d2..e66f9e20a 100755
--- a/production/testScripts/test_runTests2.xml.sh
+++ b/production/testScripts/test_runTests2.xml.sh
@@ -32,7 +32,7 @@ function clean()
}
-source localbuildproperties.shsource
+source localBuildProperties.shsource
# Different versions of Ant are specified here in test script, just to confirm
# nothing is specific to any recent version of ant. (Though, some of the machines
# have ant 1.6 set as 'default'!)
@@ -53,7 +53,7 @@ export PATH=${JAVA_HOME}/bin:${ANT_HOME}/bin:/usr/local/bin:/usr/bin:/bin:${HOME
# This variable signals parts of the script that we are testing the test scripts,
# and should not actually start the tests.
export TESTING_TEST_XML=true
-export ANT_OPTS=-Djava.io.tmpdir=${WORKSPACE}/tmp -Xms500m -Xmx500m
+export ANT_OPTS=-Xms1024m -Xmx1024m -Djava.io.tmpdir=${WORKSPACE}/tmp
if [[ "$1" == "-c" ]]
then

Back to the top
diff --git a/production/testScripts/configuration/sdk.tests/testConfigs/linux/testAll.sh b/production/testScripts/configuration/sdk.tests/testConfigs/linux/testAll.sh
index 61185057e..5e1ca1985 100644
--- a/production/testScripts/configuration/sdk.tests/testConfigs/linux/testAll.sh
+++ b/production/testScripts/configuration/sdk.tests/testConfigs/linux/testAll.sh
@@ -3,13 +3,13 @@
echo "command line as passed into $(basename ${0}): ${*}"
echo "command line (quoted) as passed into $(basename ${0}): ${@}"
# This file, localTestsProperties.shsource, should never exist or be needed for production machine,
# but allows an easy way for a "local user" to provide this file
# somewhere on the search path ($HOME/bin is common),
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
# such as for jvm
-source localTestsProperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
if [[ -z "${propertyFile}" ]]
then
@@ -34,7 +34,7 @@ echo "PWD: $PWD"
export jvm=${jvm:-/shared/common/jdk-1.6.x86_64/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
# this value in localTestsProperties.shsource. (
eclipseArch=${eclipseArch:-x86_64}
# production.properties is used in production tests,
@@ -3,13 +3,13 @@
echo "command line as passed into $(basename ${0}): ${*}"
echo "command line (quoted) as passed into $(basename ${0}): ${@}"
-# This file, localTestsProperties.shsource, should never exist or be needed for production machine,
+# This file, localBuildProperties.shsource, should never exist or be needed for production machine,
# but allows an easy way for a "local user" to provide this file
# somewhere on the search path ($HOME/bin is common),
@@ -34,7 +34,7 @@ echo "PWD: $PWD"
export jvm=${jvm:-/shared/common/jdk-1.6.x86_64/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
-# this value in localTestsProperties.shsource. (
+# this value in localBuildProperties.shsource. (
eclipseArch=${eclipseArch:-x86_64}
# production.properties is used in production tests,
diff --git a/production/testScripts/configuration/sdk.tests/testConfigs/linux32/testAll.sh b/production/testScripts/configuration/sdk.tests/testConfigs/linux32/testAll.sh
index 825c1e9fa..b494d9d11 100644
--- a/production/testScripts/configuration/sdk.tests/testConfigs/linux32/testAll.sh
+++ b/production/testScripts/configuration/sdk.tests/testConfigs/linux32/testAll.sh
@@ -3,13 +3,13 @@
echo "command line as passed into $(basename ${0}): ${*}"
echo "command line (quoted) as passed into $(basename ${0}): ${@}"
# This file, localTestsProperties.shsource, should never exist or be needed for production machine,
# but allows an easy way for a "local user" to provide this file
# somewhere on the search path ($HOME/bin is common),
# and it will be included here, thus can provide "override values"
# to those defined by defaults for production machine.,
# such as for jvm
-source localTestsProperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
if [[ -z "${propertyFile}" ]]
then
@@ -34,7 +34,7 @@ echo "PWD: $PWD"
export jvm=${jvm:-/shared/common/jdk-1.6.x86_64/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
# this value in localTestsProperties.shsource. (
eclipseArch=${eclipseArch:-x86_64}
# production.properties is used in production tests,
@@ -3,13 +3,13 @@
echo "command line as passed into $(basename ${0}): ${*}"
echo "command line (quoted) as passed into $(basename ${0}): ${@}"
-# This file, localTestsProperties.shsource, should never exist or be needed for production machine,
+# This file, localBuildProperties.shsource, should never exist or be needed for production machine,
# but allows an easy way for a "local user" to provide this file
# somewhere on the search path ($HOME/bin is common),
@@ -34,7 +34,7 @@ echo "PWD: $PWD"
export jvm=${jvm:-/shared/common/jdk-1.6.x86_64/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
-# this value in localTestsProperties.shsource. (
+# this value in localBuildProperties.shsource. (
eclipseArch=${eclipseArch:-x86_64}
# production.properties is used in production tests,
diff --git a/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh b/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh
index ef4fa01f3..d8319641f 100644
--- a/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh
+++ b/production/testScripts/configuration/sdk.tests/testConfigs/macmini/testAll.sh
@@ -8,14 +8,14 @@ ulimit -c unlimited
# to those defined by defaults for production machine.,
# such as for vmcmd
-source localTestsProperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
echo "PWD: $PWD"
vmcmd=${vmcmd:-/System/Library/Frameworks/JavaVM.framework/Versions/1.5.0/Commands/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
# this value in localTestsProperties.shsource.
eclipseArch=${eclipseArch:-x86}
# vm.properties is used by default on production machines, but will
@@ -8,14 +8,14 @@ ulimit -c unlimited
vmcmd=${vmcmd:-/System/Library/Frameworks/JavaVM.framework/Versions/1.5.0/Commands/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
-# this value in localTestsProperties.shsource.
+# this value in localBuildProperties.shsource.
eclipseArch=${eclipseArch:-x86}
# vm.properties is used by default on production machines, but will
diff --git a/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh b/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh
index 7ad15b1a5..d930bd4f6 100644
--- a/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh
+++ b/production/testScripts/configuration/sdk.tests/testConfigs/macosx/testAll.sh
@@ -8,13 +8,13 @@ ulimit -c unlimited
# to those defined by defaults for production machine.,
# such as for vmcmd
-source localTestsProperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
echo "PWD: $PWD"
vmcmd=${vmcmd:-/Library/Java/JavaVirtualMachines/jdk1.7.0_51.jdk/Contents/Home/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
# this value in localTestsProperties.shsource.
eclipseArch=${eclipseArch:-x86_64}
# vm.properties is used by default on production machines, but will
@@ -8,13 +8,13 @@ ulimit -c unlimited
vmcmd=${vmcmd:-/Library/Java/JavaVirtualMachines/jdk1.7.0_51.jdk/Contents/Home/jre/bin/java}
# production machine is x86_64, but some local setups may be 32 bit and will need to provide
-# this value in localTestsProperties.shsource.
+# this value in localBuildProperties.shsource.
eclipseArch=${eclipseArch:-x86_64}
# vm.properties is used by default on production machines, but will
diff --git a/production/testScripts/startTests.sh b/production/testScripts/startTests.sh
index 39366a71b..1d1c96159 100755
--- a/production/testScripts/startTests.sh
+++ b/production/testScripts/startTests.sh
@@ -1,8 +1,8 @@
#!/usr/bin/env bash
# this localbuildproperties.shsource file is to ease local builds to override some variables.
# It should not be used for production builds.
-source localbuildproperties.shsource 2>/dev/null
+source localBuildProperties.shsource 2>/dev/null
export BUILD_HOME=${BUILD_HOME:-/shared/eclipse/builds}
# Small utility to start unit tests (or re-run them) after a build
@@ -1,8 +1,8 @@
#!/usr/bin/env bash
-# this localbuildproperties.shsource file is to ease local builds to override some variables.
+# this localBuildProperties.shsource file is to ease local builds to override some variables.
# It should not be used for production builds.